@@ -83,8 +83,9 @@ main (int argc, char *argv[])
         struct board *veleng_init ();
 
 
-        bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-        textdomain (PACKAGE);
+        bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+        textdomain (GETTEXT_PACKAGE);
 
         gnome_program_init (APPNAME, VERSION,
                             LIBGNOMEUI_MODULE,
