@@ -1,5 +1,4 @@
-/* -*-mode:c; c-style:k&r; c-basic-offset:4; -*-
- *
+/*
  * gnect main.h
  *
  */
@@ -35,11 +34,14 @@
 #define PACKAGE_THEME_DIR       GNECT_DATA_DIR  APPNAME  G_DIR_SEPARATOR_S
 
 #define FNAME_GNECT_ICON        BASE_PIXMAP_DIR    "gnect-icon.png"
-#define FNAME_GNECT_LOGO        PACKAGE_PIXMAP_DIR "gnect-about.png"
+#define FNAME_GNECT_LOGO        FNAME_GNECT_ICON /* PACKAGE_PIXMAP_DIR "gnect-about.png" */
 
 #define GNECT_ICON_WIDTH        48
 #define GNECT_ICON_HEIGHT       48
 
+#define GNECT_LOGO_WIDTH        400
+#define GNECT_LOGO_HEIGHT       64
+
 #define PLAYER_1                0
 #define PLAYER_2                1
 #define DRAWN_GAME              2
