@@ -122,7 +122,7 @@ GnomeUIInfo game_menu[] = {
 	
 	GNOMEUIINFO_SEPARATOR,
 
-        GNOMEUIINFO_MENU_EXIT_ITEM(quit_game_cb, NULL),
+        GNOMEUIINFO_MENU_QUIT_ITEM(quit_game_cb, NULL),
 
 	GNOMEUIINFO_END
 };
@@ -231,11 +231,11 @@ void quit_game_maybe(GtkWidget *widget, gint button)
 			gtk_timeout_remove(white_computer_id);
 
 		if(buffer_pixmap)
-			gdk_pixmap_unref(buffer_pixmap);
+			g_object_unref(buffer_pixmap);
 		if(tiles_pixmap)
-			gdk_pixmap_unref(tiles_pixmap);
+			g_object_unref(tiles_pixmap);
 		if(tiles_mask)
-			gdk_pixmap_unref(tiles_mask);
+			g_object_unref(tiles_mask);
 
 		gtk_main_quit();
 	}
@@ -243,15 +243,32 @@ void quit_game_maybe(GtkWidget *widget, gint button)
 
 void quit_game_cb(GtkWidget *widget, gpointer data)
 {
-	GtkWidget *box;
+	GtkWidget *dialog;
 
 	if(game_in_progress) {
-		box = gnome_message_box_new(_("Do you really want to quit?"), GNOME_MESSAGE_BOX_QUESTION, GNOME_STOCK_BUTTON_YES, GNOME_STOCK_BUTTON_NO, NULL);
-		gnome_dialog_set_parent(GNOME_DIALOG(box), GTK_WINDOW(window));
-		gnome_dialog_set_default(GNOME_DIALOG(box), 0);
-		gtk_window_set_modal(GTK_WINDOW(box), TRUE);
-		gtk_signal_connect(GTK_OBJECT(box), "clicked", (GtkSignalFunc)quit_game_maybe, NULL);
-		gtk_widget_show(box);
+		gint response;
+
+		dialog = gtk_dialog_new_with_buttons (NULL,
+				GTK_WINDOW (window),
+				GTK_DIALOG_MODAL,
+				GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+				GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+				NULL);
+		{
+			GtkWidget *label = gtk_label_new (_("Do you really want to quit?"));
+			gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox),
+					label);
+		}
+
+		gtk_dialog_set_default_response (GTK_DIALOG (dialog),
+				GTK_RESPONSE_REJECT);
+
+		gtk_widget_show_all (dialog);
+		response = gtk_dialog_run (GTK_DIALOG(dialog));
+		gtk_widget_destroy (dialog);
+
+		if (response == GTK_RESPONSE_ACCEPT)
+			quit_game_maybe(NULL, 0);
 	} else {
 		quit_game_maybe(NULL, 0);
 	}
@@ -380,12 +397,12 @@ void white_level_cb(GtkWidget *widget, gpointer data)
 void about_cb(GtkWidget *widget, gpointer data)
 {
 	static GtkWidget *about;
-
+	GdkPixbuf *pixbuf = NULL;
 	const gchar *authors[] = {"Ian Peters", NULL};
 	const gchar *documenters[] = {
 	    			      NULL
     	};
-    	const gchar *translator_credits = _("");
+    	const gchar *translator_credits = _("translator_credits");
 	
 	if (about != NULL) {
 		gdk_window_raise (about->window);
@@ -393,18 +410,31 @@ void about_cb(GtkWidget *widget, gpointer data)
 		return;
 	}
 
+	{
+		char *filename = NULL;
+
+		filename = gnome_program_locate_file (NULL,
+				GNOME_FILE_DOMAIN_PIXMAP,  ("iagno.png"),
+				TRUE, NULL);
+		if (filename != NULL)
+		{
+			pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+			g_free (filename);
+		}
+	}
+
 	about = gnome_about_new(_("Iagno"), VERSION, 
 			        _("(C) 1998 Ian Peters"),
 				_("Send comments and bug reports to: itp@gnu.org\nTiles under the General Public License."), 
 				(const char **)authors, 
 				(const char **)documenters,
-			     	(const char *)translator_credits,
-				NULL);
+				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				pixbuf);
 			
 			
-	gtk_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
+	g_signal_connect (GTK_OBJECT (about), "destroy", GTK_SIGNAL_FUNC
 			(gtk_widget_destroyed), &about);
-	gnome_dialog_set_parent(GNOME_DIALOG(about), GTK_WINDOW(window));
+	gtk_window_set_transient_for (GTK_WINDOW(about), GTK_WINDOW(window));
 
 	gtk_widget_show(about);
 }
@@ -416,7 +446,7 @@ void properties_cb (GtkWidget *widget, gpointer data)
 
 gint expose_event(GtkWidget *widget, GdkEventExpose *event)
 {
-	gdk_draw_pixmap(widget->window, widget->style->fg_gc[GTK_WIDGET_STATE(widget)], buffer_pixmap, event->area.x, event->area.y, event->area.x, event->area.y, event->area.width, event->area.height);
+	gdk_draw_drawable(widget->window, widget->style->fg_gc[GTK_WIDGET_STATE(widget)], buffer_pixmap, event->area.x, event->area.y, event->area.x, event->area.y, event->area.width, event->area.height);
 
 	return(FALSE);
 }
@@ -461,13 +491,13 @@ gint button_press_event(GtkWidget *widget, GdkEventButton *event)
 
 void gui_draw_pixmap(gint which, gint x, gint y)
 {
-	gdk_draw_pixmap(drawing_area->window, gridGC[0], tiles_pixmap, (which % 8) * TILEWIDTH, (which / 8) * TILEHEIGHT, x * (TILEWIDTH+GRIDWIDTH), y * (TILEHEIGHT+GRIDWIDTH), TILEWIDTH, TILEHEIGHT);
-	gdk_draw_pixmap(buffer_pixmap, gridGC[0], tiles_pixmap, (which % 8) * TILEWIDTH, (which / 8) * TILEHEIGHT, x * (TILEWIDTH+GRIDWIDTH), y * (TILEHEIGHT+GRIDWIDTH), TILEWIDTH, TILEHEIGHT);
+	gdk_draw_drawable(drawing_area->window, gridGC[0], tiles_pixmap, (which % 8) * TILEWIDTH, (which / 8) * TILEHEIGHT, x * (TILEWIDTH+GRIDWIDTH), y * (TILEHEIGHT+GRIDWIDTH), TILEWIDTH, TILEHEIGHT);
+	gdk_draw_drawable(buffer_pixmap, gridGC[0], tiles_pixmap, (which % 8) * TILEWIDTH, (which / 8) * TILEHEIGHT, x * (TILEWIDTH+GRIDWIDTH), y * (TILEHEIGHT+GRIDWIDTH), TILEWIDTH, TILEHEIGHT);
 }
 
 void gui_draw_pixmap_buffer(gint which, gint x, gint y)
 {
-	gdk_draw_pixmap(buffer_pixmap, gridGC[0], tiles_pixmap, (which % 8) * TILEWIDTH, (which / 8) * TILEHEIGHT, x * (TILEWIDTH+GRIDWIDTH), y * (TILEHEIGHT+GRIDWIDTH), TILEWIDTH, TILEHEIGHT);
+	gdk_draw_drawable(buffer_pixmap, gridGC[0], tiles_pixmap, (which % 8) * TILEWIDTH, (which / 8) * TILEHEIGHT, x * (TILEWIDTH+GRIDWIDTH), y * (TILEHEIGHT+GRIDWIDTH), TILEWIDTH, TILEHEIGHT);
 }
 
 void gui_draw_grid()
@@ -481,7 +511,7 @@ void gui_draw_grid()
 					  0, i*BOARDHEIGHT/8-1, BOARDWIDTH, i*BOARDHEIGHT/8-1);
 	}
 	
-	gdk_draw_pixmap(drawing_area->window, gridGC[0], buffer_pixmap, 0, 0, 0, 0, BOARDWIDTH, BOARDHEIGHT);
+	gdk_draw_drawable(drawing_area->window, gridGC[0], buffer_pixmap, 0, 0, 0, 0, BOARDWIDTH, BOARDHEIGHT);
 }
 
 void load_pixmaps()
@@ -494,10 +524,11 @@ void load_pixmaps()
 	g_return_if_fail (tile_set != NULL && tile_set [0] != '0');
 
 	tmp = g_strconcat("iagno/", tile_set, NULL);
-	fname = gnome_unconditional_pixmap_file(tmp);
+	fname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
+			tmp, FALSE, NULL);
 	g_free(tmp);
 
-	if(!g_file_exists(fname)) {
+	if(!g_file_test(fname, G_FILE_TEST_EXISTS|G_FILE_TEST_IS_REGULAR)) {
 		g_print(_("Could not find \'%s\' pixmap file for Iagno\n"), fname);
 		exit(1);
 	}
@@ -681,25 +712,23 @@ void create_window()
 	window = gnome_app_new("iagno", _("Iagno"));
 
 	gtk_widget_realize(window);
-	gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, TRUE);
-	gtk_signal_connect(GTK_OBJECT(window), "delete_event", GTK_SIGNAL_FUNC(quit_game_cb), NULL);
+	gtk_window_set_resizable(GTK_WINDOW(window), FALSE);
+	g_signal_connect(GTK_OBJECT(window), "delete_event", GTK_SIGNAL_FUNC(quit_game_cb), NULL);
 
 	gnome_app_create_menus(GNOME_APP(window), mainmenu);
 
-	gtk_widget_push_visual (gdk_rgb_get_visual ());
-	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
+	/* gtk_widget_push_colormap (gdk_rgb_get_cmap ()); */
 
 	drawing_area = gtk_drawing_area_new();
 
 	gtk_widget_pop_colormap ();
-	gtk_widget_pop_visual ();
 
 	gnome_app_set_contents(GNOME_APP(window), drawing_area);
 
-	gtk_drawing_area_size(GTK_DRAWING_AREA(drawing_area), BOARDWIDTH, BOARDHEIGHT);
-	gtk_signal_connect(GTK_OBJECT(drawing_area), "expose_event", GTK_SIGNAL_FUNC(expose_event), NULL);
-	gtk_signal_connect(GTK_OBJECT(window), "configure_event", GTK_SIGNAL_FUNC(configure_event), NULL);
-	gtk_signal_connect(GTK_OBJECT(drawing_area), "button_press_event", GTK_SIGNAL_FUNC(button_press_event), NULL);
+	gtk_widget_set_size_request(GTK_WIDGET(drawing_area), BOARDWIDTH, BOARDHEIGHT);
+	g_signal_connect(GTK_OBJECT(drawing_area), "expose_event", GTK_SIGNAL_FUNC(expose_event), NULL);
+	g_signal_connect(GTK_OBJECT(window), "configure_event", GTK_SIGNAL_FUNC(configure_event), NULL);
+	g_signal_connect(GTK_OBJECT(drawing_area), "button_press_event", GTK_SIGNAL_FUNC(button_press_event), NULL);
 	gtk_widget_set_events(drawing_area, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK);
 	gtk_widget_show(drawing_area);
 
@@ -757,9 +786,9 @@ void gui_status()
 	gchar message[3];
 
 	sprintf(message, _("%.2d"), bcount);
-	gtk_label_set(GTK_LABEL(black_score), message);
+	gtk_label_set_text(GTK_LABEL(black_score), message);
 	sprintf(message, _("%.2d"), wcount);
-	gtk_label_set(GTK_LABEL(white_score), message);
+	gtk_label_set_text(GTK_LABEL(white_score), message);
 }
 
 void gui_message(gchar *message)
@@ -804,15 +833,15 @@ void set_bg_color()
 	GdkImage *tmpimage;
 	GdkColor bgcolor;
 
-	tmpimage = gdk_image_get(tiles_pixmap, 0, 0, 1, 1);
+	tmpimage = gdk_drawable_get_image (tiles_pixmap, 0, 0, 1, 1);
 	bgcolor.pixel = gdk_image_get_pixel(tmpimage, 0, 0);
 	gdk_window_set_background(drawing_area->window, &bgcolor);
 
 	if (gridGC[0])
-	  gdk_gc_destroy(gridGC[0]);
+	  g_object_unref(gridGC[0]);
 	gridGC[0] = gdk_gc_new (drawing_area->window);
 	if (gridGC[1])
-	  gdk_gc_destroy(gridGC[1]);
+	  g_object_unref(gridGC[1]);
 	gridGC[1] = gdk_gc_new (drawing_area->window);
 
 	gdk_gc_copy (gridGC [0],drawing_area->style->bg_gc[0]);
@@ -830,14 +859,7 @@ void set_bg_color()
 				    GDK_LINE_ON_OFF_DASH,
 				    GDK_CAP_BUTT, GDK_JOIN_MITER);
 	
-	gdk_image_destroy (tmpimage);
-}
-
-static char *nstr(int n)
-{
-	char buf[20];
-	sprintf(buf, "%d", n);
-	return strdup(buf);
+	g_object_unref (tmpimage);
 }
 
 static int save_state(GnomeClient *client, gint phase, GnomeRestartStyle save_style, gint shutdown, GnomeInteractStyle interact_style, gint fast, gpointer client_data)
@@ -851,15 +873,15 @@ static int save_state(GnomeClient *client, gint phase, GnomeRestartStyle save_st
 	i = 0;
 	argv[i++] = (char *)client_data;
 	argv[i++] = "-x";
-	argv[i++] = nstr(xpos);
+	argv[i++] = g_strdup_printf("%d", xpos);
 	argv[i++] = "-y";
-	argv[i++] = nstr(ypos);
+	argv[i++] = g_strdup_printf("%d", ypos);
 
 	gnome_client_set_restart_command(client, i, argv);
 	gnome_client_set_clone_command(client, 0, NULL);
 
-	free(argv[2]);
-	free(argv[4]);
+	g_free(argv[2]);
+	g_free(argv[4]);
 
 	return TRUE;
 }
@@ -878,16 +900,20 @@ int main(int argc, char **argv)
 	gettimeofday(&tv, NULL);
 	srand(tv.tv_usec);
 
-	gnome_init_with_popt_table("iagno", VERSION, argc, argv, options, 0, NULL);
+	gnome_program_init ("iagno", VERSION,
+			LIBGNOMEUI_MODULE,
+			argc, argv,
+			GNOME_PARAM_POPT_TABLE, options,
+			NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/iagno.png");
 	client= gnome_master_client();
 
-	gtk_object_ref(GTK_OBJECT(client));
+	g_object_ref(GTK_OBJECT(client));
 	gtk_object_sink(GTK_OBJECT(client));
 
-	gtk_signal_connect(GTK_OBJECT(client), "save_yourself", GTK_SIGNAL_FUNC(save_state), argv[0]);
-	gtk_signal_connect(GTK_OBJECT(client), "die", GTK_SIGNAL_FUNC(quit_game_cb), argv[0]);
-	
+	g_signal_connect(GTK_OBJECT(client), "save_yourself", GTK_SIGNAL_FUNC(save_state), argv[0]);
+	g_signal_connect(GTK_OBJECT(client), "die", GTK_SIGNAL_FUNC(quit_game_cb), argv[0]);
+
 	create_window();
 	
 	load_properties ();
@@ -895,7 +921,7 @@ int main(int argc, char **argv)
 	load_pixmaps();
 
 	if(session_xpos >= 0 && session_ypos >= 0) {
-		gtk_widget_set_uposition(window, session_xpos, session_ypos);
+		gdk_window_move(window->window, session_xpos, session_ypos);
 	}
 
 	gtk_widget_show(window);
