@@ -2,11 +2,12 @@
 #include "config.h"
 #endif
 
+#include <gnome.h>
+
 #include "objects.h"
 #include "x11.h"
 #include "Strings.h"
 
-#include <libgnomeui/gnome-window-icon.h>
 GtkWidget *toplevel, *menubar, *field;
 GtkWidget *scorebox, *endgamebox;
 GtkWidget *warpbox, *quitbox, *newgamebox, *pausebox;
@@ -42,11 +43,14 @@ void UI::resume_game() {
 /*******************/
 
 void UI::initialize(int argc, char **argv, const struct poptOption *options) {
-        gnome_init_with_popt_table(PACKAGE, VERSION, argc, argv,
-				   options, 0, NULL);
+	gnome_program_init (PACKAGE, VERSION,
+			LIBGNOMEUI_MODULE,
+			argc, argv,
+			GNOME_PARAM_POPT_TABLE, options,
+			NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/xbill.png");
 	toplevel = gnome_app_new("gnome-xbill", "Gnome xBill");
-	gtk_signal_connect(GTK_OBJECT(toplevel), "destroy",
+	g_signal_connect(GTK_OBJECT(toplevel), "destroy",
 			   GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
 	gtk_widget_realize(toplevel);
 	display = toplevel->window;
@@ -58,7 +62,7 @@ void UI::make_mainwin() {
 	CreateMenuBar(toplevel);
 
 	field = gtk_drawing_area_new();
-	gtk_drawing_area_size(GTK_DRAWING_AREA(field), game.scrwidth,
+	gtk_widget_set_size_request(GTK_WIDGET(field), game.scrwidth,
 			      game.scrheight);
 
 	gnome_app_set_contents(GNOME_APP(toplevel), field);
@@ -67,11 +71,14 @@ void UI::make_mainwin() {
 	gtk_widget_ensure_style(field);
 	style = field->style;
 	colormap = style->colormap;
+	gdk_color_parse ("white", &white);
 
 	/* try to alloc color */
 	if (colormap)
-		gdk_color_white(colormap, &white);
-	else if (gdk_color_white(gdk_colormap_get_system(), &white)) {
+		gdk_colormap_alloc_color (colormap, &white,
+				FALSE, FALSE);
+	else if (gdk_colormap_alloc_color (gdk_colormap_get_system(),
+				&white, FALSE, FALSE)) {
 		style = gtk_style_copy(gtk_widget_get_style(GTK_WIDGET(field)));
 
 		/* set new style */
@@ -89,21 +96,21 @@ void UI::make_mainwin() {
 			             GDK_ENTER_NOTIFY_MASK |
 			             GDK_EXPOSURE_MASK);
 
-	gtk_signal_connect(GTK_OBJECT(field), "button_press_event",
+	g_signal_connect(GTK_OBJECT(field), "button_press_event",
 			   GTK_SIGNAL_FUNC(button_press_eh), NULL);
-	gtk_signal_connect(GTK_OBJECT(field), "button_release_event",
+	g_signal_connect(GTK_OBJECT(field), "button_release_event",
 			   GTK_SIGNAL_FUNC(button_release_eh), NULL);
-	gtk_signal_connect(GTK_OBJECT(field), "leave_notify_event",
+	g_signal_connect(GTK_OBJECT(field), "leave_notify_event",
 			   GTK_SIGNAL_FUNC(leave_window_eh), NULL);
-	gtk_signal_connect(GTK_OBJECT(field), "enter_notify_event",
+	g_signal_connect(GTK_OBJECT(field), "enter_notify_event",
 			   GTK_SIGNAL_FUNC(enter_window_eh), NULL);
-	gtk_signal_connect(GTK_OBJECT(field), "expose_event",
+	g_signal_connect(GTK_OBJECT(field), "expose_event",
 			   GTK_SIGNAL_FUNC(redraw_window_eh), NULL);
 	
 	gtk_widget_realize(field);
 	window = field->window;
 
-	gtk_window_set_policy(GTK_WINDOW(toplevel), FALSE, FALSE, FALSE);
+	gtk_window_set_resizable(GTK_WINDOW(toplevel), FALSE);
         gtk_widget_show(toplevel);
 }
 
@@ -136,10 +143,10 @@ void UI::make_windows() {
 
 void UI::popup_dialog (int dialog) {
 	GtkWidget *w;
-	switch (dialog) {
-		case game.SCORE: w = scorebox; break;
-		case game.ENDGAME: w = endgamebox; break;
-	}
+	if (dialog == game.SCORE)
+		w = scorebox;
+	else if (dialog == game.ENDGAME)
+		w = endgamebox;
 	popup (NULL, &w);
 }
 
@@ -148,16 +155,14 @@ void UI::popup_dialog (int dialog) {
 /*********************/
 
 void UI::set_cursor(int cursor) {
-	switch (cursor) {
-	case game.BUCKETC:
-	        gdk_window_set_cursor(window, bucket.cursor.cursor); break;
-	case game.DOWNC:
-		gdk_window_set_cursor(window, downcursor.cursor); break;
-	case game.DEFAULTC:
-		gdk_window_set_cursor(window, defaultcursor.cursor); break;
-	default:
-		gdk_window_set_cursor(window, OS.cursor[cursor].cursor);
-	}
+	if (cursor == game.BUCKETC)
+	        gdk_window_set_cursor(window, bucket.cursor.cursor);
+	else if (cursor == game.DOWNC)
+		gdk_window_set_cursor(window, downcursor.cursor);
+	else if (cursor == game.DEFAULTC)
+		gdk_window_set_cursor(window, defaultcursor.cursor);
+	else
+ 		gdk_window_set_cursor(window, OS.cursor[cursor].cursor);
 }
 
 void UI::load_cursors() {
@@ -184,7 +189,7 @@ void UI::graph_init() {
 
 	gtk_widget_ensure_style(field);
 	gtk_widget_realize(field);
-	font = field->style->font;
+
 	offscreen = gdk_pixmap_new(field->window, game.scrwidth, game.scrheight,
 				   -1);
 }
@@ -195,13 +200,13 @@ void UI::clear() {
 }
 
 void UI::refresh() {
-        gdk_draw_pixmap(window, stdgc, offscreen, 0,0, 0,0,
+        gdk_draw_drawable(window, stdgc, offscreen, 0,0, 0,0,
 			game.scrwidth, game.scrheight);
 }
 
 void UI::draw (Picture pict, int x, int y) {
         gdk_gc_set_clip_origin(pict.gc, x, y);
-	gdk_draw_pixmap(offscreen, pict.gc, pict.pix, 0,0, x,y,
+	gdk_draw_drawable(offscreen, pict.gc, pict.pix, 0,0, x,y,
 			pict.width, pict.height);
 }
 
@@ -215,7 +220,16 @@ void UI::draw_line(int x1, int y1, int x2, int y2) {
 }
 
 void UI::draw_str(char *str, int x, int y) {
-        gdk_draw_string(offscreen, font, stdgc, x,y, str);
+	PangoLayout *layout = gtk_widget_create_pango_layout (field, str);
+	int h;
+
+	pango_layout_get_pixel_size (layout, NULL, &h);
+
+	y -= h;
+
+	gdk_draw_layout (offscreen, stdgc, x, y, layout);
+
+	g_object_unref (layout);
 }
 
 
